{% extends 'base.html' %}

{% block title %}Chef nodes{% endblock %}

{% macro list_nodes(node_names, use_columns=True) -%}
  <ul {% if use_columns %}class="attempt-columns"{% endif %}>
  {% for name in node_names %}
    <li>
      <a href="{{ url_for('.node', name=name) }}">
        <code>{{ name }}</code>
      </a>
    </li>
  {% endfor %}
  </ul>
{%- endmacro %}

{% block content %}
  {{ list_nodes(nodes) }}
{% endblock %}
